# :black_circle: :white_circle: pyreversi :black_circle: :white_circle: 

pyreversi is a reversi game in your terminal with IA available.

# Démo

![image](./demo_01.png)


# 🚀 How to use **pyreversi**

``pyreversi``

## IA options

- ``-b --blackbot [int]`` : black player is a bot, with level [int]
- ``-w --whitebot [int]`` : white player is a bot, with level [int]

- level 0 : one in available choice
- level 1 : max increase score
- level 2 : max increase score + target corner + not offer corner
- level 3 : max increase score + target corner + not offer corner considering next turn (with IA level2)
- level 4 : max increase score + target corner + not offer corner considering next turn + consider safe place (with IA level2)
## Other options

- ``-u/--update`` update the package
- ``-v/--verbose`` verbose mode
- ``-a/--auto`` auto mode (disable "press any key")
- ``-r/--random`` random choice in the set of best choices for IA
# ⚙️ Install

See [this page](INSTALL.md)

# :construction_worker: Contribution

See [this page](CONTRIBUTING.md)

# :package: Changelog

See [this page](CHANGELOG.md)


# License

MIT License

Copyright (c) 2021 [thib1984](https://github.com/thib1984)

See [this page](LICENSE.txt) for details
